@@ -1,6 +1,6 @@
 /* sdlgfx.c --- Additional Graphics functions for Guile SDL
  *
- * Copyright (C) 2003, 2004, 2005, 2007, 2008, 2009, 2011 Thien-Thi Nguyen
+ * Copyright (C) 2003-2005, 2007-2009, 2011, 2013 Thien-Thi Nguyen
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -12,27 +12,23 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #define GUILE_SDL_OPTIONAL_MODULE  1
 #include "guile-sdl.h"
 #include <stdio.h>
 #include <alloca.h>
+#include "snuggle/finangle.h"
 #include "b-uv.h"
 
 IMPORT_MODULE (sdlsup, "(sdl sdl)");
 SELECT_MODULE_VAR (obtw, sdlsup, "%%Guile-SDL-obtw");
-#if GI_LEVEL_NOT_YET_1_8
+#if ! GI_LEVEL_1_8
 IMPORT_SRFI4 ();
 SELECT_UVEC_PREDICATE (s16);
 #define scm_s16vector_p(obj)  CALL1 (s16v_p, obj)
-
-/* For backward compatability (EVENTUALLY ZONKABLE).  */
-DEFINE_ANY_TO (s16)
 #endif
 
 DEFINE_STRUCT_AND_COPY_FUNC (s16, Sint16)
@@ -655,28 +651,26 @@ draw string @var{text} with @var{color} (a number).  */)
 
 
 static SCM frot_enum;
-static valaka_t frot_eback[] = {
-  { 0, { "none" } },
-  { 1, { "clockwise" } },
-  { 2, { "upside-down" } },
-  { 3, { "counter-clockwise" } }
-};
+#include "k/frot.c"
 
 PRIMPROC
 (font_rotation_x, "font-rotation!", 1, 0, 0,
  (SCM rotation),
  doc: /***********
-Set the rotation for glyphs drawn by @code{draw-character}
-and @code{draw-string} to @var{rotation}, one of the (symbolic)
-elements of enumstash @code{font-rotations}.
-Any other value is taken as @code{none}.  */)
+Set the rotation for glyphs drawn by @code{draw-character} and
+@code{draw-string} to @var{rotation} (an integer or symbol), one of:
+
+@example
+0  none
+1  clockwise
+2  upside-down
+3  counter-clockwise
+@end example  */)
 {
 #define FUNC_NAME s_font_rotation_x
-  int crotation;
+  DECLINIT_SYM2NUM_CC       (1, frot_enum);
+  int crotation = ENUM2LONG (1, rotation);
 
-  crotation = SYMBOLP (rotation)
-    ? GSDL_ENUM2LONG (rotation, frot_enum, 1)
-    : 0;
   gfxPrimitivesSetFontRotation (crotation);
   RETURN_UNSPECIFIED;
 #undef FUNC_NAME
@@ -826,7 +820,7 @@ box RGBA or Y information'' and is in 32-bit RGBA format.  */)
 
 #include "SDL_gfx/SDL_framerate.h"
 
-static long fpsmgr_tag;
+static smob_tag_t fpsmgr_tag;
 
 #define fpsmgr_nick "SDL-FPS-Manager"
 
@@ -845,7 +839,7 @@ free_fpsmgr (SCM fpsmgr)
 
 static
 int
-print_fpsmgr (SCM fpsmgr, SCM port, scm_print_state *pstate)
+print_fpsmgr (SCM fpsmgr, SCM port, UNUSED scm_print_state *pstate)
 {
   FPSmanager *m = UNPACK_FPSMGR (fpsmgr);
   char buf[24];
@@ -1051,7 +1045,7 @@ check_3_surfaces (unsigned char **pa, SDL_Surface *a,
                             &s2, UNPACK_SURFACE (src2), \
                             &d,  UNPACK_SURFACE (dst),  \
                             &len))                      \
-    RETURN_FALSE
+    return BOOL_FALSE
 
 static int
 check_2_surfaces (unsigned char **pa, SDL_Surface *a,
@@ -1081,7 +1075,7 @@ check_2_surfaces (unsigned char **pa, SDL_Surface *a,
   if (0 > check_2_surfaces (&s, UNPACK_SURFACE (src),   \
                             &d, UNPACK_SURFACE (dst),   \
                             &len))                      \
-    RETURN_FALSE
+    return BOOL_FALSE
 
 PRIMPROC
 (imfi_add, "imfi-add", 3, 0, 0,
@@ -1496,8 +1490,13 @@ init_module (void)
 
   btw = UNPACK_POINTER (CALL0 (obtw));
 
-  /* enums */
-  frot_enum = DEFINE_ENUM ("font-rotations", frot_eback);
+  {
+    kp_init_t allp[] = {
+      { &frot_enum, &frot_kp }
+    };
+
+    REGISTER_KP_V (allp);
+  }
 }
 
 MOD_INIT_LINK_THUNK ("sdl gfx", sdl_gfx, init_module)
