@@ -1,7 +1,6 @@
 /* sdlsurface.c --- SDL Surface functions
  *
- * Copyright (C) 2003, 2004, 2005, 2007, 2008, 2009,
- *   2011, 2013 Thien-Thi Nguyen
+ * Copyright (C) 2003-2005, 2007-2009, 2011, 2013, 2015 Thien-Thi Nguyen
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,15 +12,13 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "guile-sdl.h"
 #include <stdio.h>
-#include <SDL/SDL_image.h>
+#include "SDL_image.h"
 #include "snuggle/finangle.h"
 #include "b-uv.h"
 
@@ -36,7 +33,6 @@ SELECT_MODULE_VAR (mk_u32v, srfi4, "make-u32vector");
 #endif
 
 static SCM kp_alpha;
-static SCM alpha_enums;
 
 
 /* smob functions */
@@ -58,7 +54,7 @@ free_surface (SCM surface)
 
 static
 int
-print_surface (SCM surface_smob, SCM port, scm_print_state *pstate)
+print_surface (SCM surface_smob, SCM port, UNUSED scm_print_state *pstate)
 {
   SDL_Surface *surface = UNPACK_SURFACE (surface_smob);
   char buf[64], sbuf[64];
@@ -332,33 +328,6 @@ Return @code{#t} if successful.  */)
 }
 
 
-PRIMPROC
-(set_color_key, "set-color-key!", 3, 0, 0,
- (SCM surface,
-  SCM flag,
-  SCM key),
- doc: /***********
-NB: This procedure is obsoleted by @code{surface-color-key!}
-and @strong{will be removed} after 2013-12-31.
-
-Set @var{surface} color key as specified by @var{flag}
-(@pxref{video flags}) and @var{key}.  */)
-{
-#define FUNC_NAME s_set_color_key
-  DECLINIT_SYM2NUM_CC (2, btw->video_flags);
-  Uint32 cflag;
-
-  ASSERT_SURFACE (surface, 1);
-  ASSERT_INTEGER (key, 3);
-
-  cflag = FLAGS2ULONG (2, flag);
-
-  RETURN_TRUE_IF_0
-    (SDL_SetColorKey (UNPACK_SURFACE (surface), cflag, C_LONG (key)));
-#undef FUNC_NAME
-}
-
-
 PRIMPROC
 (surface_alpha_x, "surface-alpha!", 2, 1, 0,
  (SCM surface, SCM alpha, SCM rle),
@@ -396,50 +365,6 @@ Return @code{#t} if successful.  */)
 }
 
 
-PRIMPROC
-(set_alpha, "set-alpha!", 2, 1, 0,
- (SCM surface,
-  SCM flag,
-  SCM alpha),
- doc: /***********
-NB: This procedure is obsoleted by @code{surface-alpha!}
-and @strong{will be removed} after 2013-12-31.
-
-Adjust whole-@var{surface} alpha as specified by
-@var{flag} (@pxref{video flags}) and @var{alpha}
-(@pxref{alpha-enum enums}, or a number 0-255).
-If @var{flag} is @code{#f}, ignore @var{alpha} completely.  */)
-{
-#define FUNC_NAME s_set_alpha
-  DECLINIT_SYM2NUM_CC (2, btw->video_flags);
-  DECLINIT_SYM2NUM_CC (3, alpha_enums);
-  Uint32 cflag;
-  Uint8 calpha;
-
-  ASSERT_SURFACE (surface, 1);
-  if (EXACTLY_FALSEP (flag) || NULLP (flag))
-    {
-      flag = SCM_BOOL_F;
-      alpha = SCM_INUM0;
-    }
-  if (UNBOUNDP (alpha))
-    alpha = SCM_INUM0;
-  else
-    ASSERT_INTEGER (alpha, 3);
-
-  cflag = (EXACTLY_FALSEP (flag)
-           ? 0
-           : FLAGS2ULONG (2, flag));
-  calpha = (Uint8) ENUM2LONG (3, alpha);
-
-  RETURN_TRUE_IF_0
-    (SDL_SetAlpha (UNPACK_SURFACE (surface),
-                   cflag,
-                   calpha));
-#undef FUNC_NAME
-}
-
-
 PRIMPROC
 (set_clip_rect, "set-clip-rect!", 1, 1, 0,
  (SCM surface,
@@ -765,7 +690,6 @@ with @var{height} x @var{width} x @var{depth-in-bytes} elements.  */)
 
 
 #include "k/alphalim.c"
-#include "k/alphalimold.c"
 
 void
 gsdl_init_surface (void)
@@ -780,7 +704,6 @@ gsdl_init_surface (void)
   /* alpha constants */
   {
     kp_init_t allp[] = {
-      { &alpha_enums, &alphalimold_kp },
       { &kp_alpha, &alphalim_kp }
     };
 
